aboutsummaryrefslogtreecommitdiffstats
path: root/shell/e-shell-window-actions.c
diff options
context:
space:
mode:
authorMatthew Barnes <mbarnes@redhat.com>2009-12-28 11:15:23 +0800
committerMatthew Barnes <mbarnes@redhat.com>2009-12-28 11:15:23 +0800
commit32bc83c91d575d7258252a9c532309e8e9015d84 (patch)
tree8d381c0716670e875eb0f637d46c0781972e4a5b /shell/e-shell-window-actions.c
parentae7307e9702f6cd1ce5a419e648ebbb9bde0b310 (diff)
downloadgsoc2013-evolution-32bc83c91d575d7258252a9c532309e8e9015d84.tar
gsoc2013-evolution-32bc83c91d575d7258252a9c532309e8e9015d84.tar.gz
gsoc2013-evolution-32bc83c91d575d7258252a9c532309e8e9015d84.tar.bz2
gsoc2013-evolution-32bc83c91d575d7258252a9c532309e8e9015d84.tar.lz
gsoc2013-evolution-32bc83c91d575d7258252a9c532309e8e9015d84.tar.xz
gsoc2013-evolution-32bc83c91d575d7258252a9c532309e8e9015d84.tar.zst
gsoc2013-evolution-32bc83c91d575d7258252a9c532309e8e9015d84.zip
Clarify "Synchronization Options" menu item.
Rename it "GNOME Pilot Synchronization" and only display the item if gnome-pilot is installed.
Diffstat (limited to 'shell/e-shell-window-actions.c')
-rw-r--r--shell/e-shell-window-actions.c12
1 files changed, 9 insertions, 3 deletions
diff --git a/shell/e-shell-window-actions.c b/shell/e-shell-window-actions.c
index 2266b005b7..79bc8b78b7 100644
--- a/shell/e-shell-window-actions.c
+++ b/shell/e-shell-window-actions.c
@@ -1306,7 +1306,7 @@ action_switcher_style_cb (GtkRadioAction *action,
*
* Activation of this action opens the Gnome Pilot settings.
*
* Main menu item: Edit -> Synchronization Options...
**/
static void
action_sync_options_cb (GtkAction *action,
@@ -1579,9 +1579,9 @@ static GtkActionEntry shell_entries[] = {
{ "sync-options",
NULL,
- N_("_Synchronization Options..."),
+ N_("GNOME Pilot _Synchronization..."),
NULL,
- N_("Set up Pilot configuration"),
+ N_("Set up GNOME Pilot configuration"),
G_CALLBACK (action_sync_options_cb) },
{ "work-offline",
@@ -1979,6 +1979,12 @@ e_shell_window_actions_init (EShellWindow *shell_window)
if (path == NULL)
gtk_action_set_visible (ACTION (SUBMIT_BUG), FALSE);
g_free (path);
+
+ /* Sychronizing your Palm PDA requires gnome-pilot. */
+ path = g_find_program_in_path ("gpilotd-control-applet");
+ if (path == NULL)
+ gtk_action_set_visible (ACTION (SYNC_OPTIONS), FALSE);
+ g_free (path);
}
GtkWidget *
@@ -1306,7 +1306,7 @@ action_switcher_style_cb (GtkRadioAction *action,
* Activation of this action opens the Gnome Pilot settings.
*
- * Main menu item: Edit -> Synchronization Options...
+ * Main menu item: Edit -> GNOME Pilot Synchronization...
**/
static void